#[non_exhaustive]
pub enum Event { Done, IccFile { icc: OwnedFd, icc_size: u32, }, Primaries { r_x: i32, r_y: i32, g_x: i32, g_y: i32, b_x: i32, b_y: i32, w_x: i32, w_y: i32, }, PrimariesNamed { primaries: WEnum<Primaries>, }, TfPower { eexp: u32, }, TfNamed { tf: WEnum<TransferFunction>, }, Luminances { min_lum: u32, max_lum: u32, reference_lum: u32, }, TargetPrimaries { r_x: i32, r_y: i32, g_x: i32, g_y: i32, b_x: i32, b_y: i32, w_x: i32, w_y: i32, }, TargetLuminance { min_lum: u32, max_lum: u32, }, TargetMaxCll { max_cll: u32, }, TargetMaxFall { max_fall: u32, }, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Done

end of information

Signals the end of information events and destroys the object.

This is a destructor, once received this object cannot be used any longer.



IccFile

ICC profile matching the image description

The icc argument provides a file descriptor to the client which may be memory-mapped to provide the ICC profile matching the image description. The fd is read-only, and if mapped then it must be mapped with MAP_PRIVATE by the client.

The ICC profile version and other details are determined by the compositor. There is no provision for a client to ask for a specific kind of a profile.

Fields

icc: OwnedFd

ICC profile file descriptor

icc_size: u32

ICC profile size, in bytes



Primaries

primaries as chromaticity coordinates

Delivers the primary color volume primaries and white point using CIE 1931 xy chromaticity coordinates.

Each coordinate value is multiplied by 1 million to get the argument value to carry precision of 6 decimals.

Fields

r_x: i32

Red x * 1M

r_y: i32

Red y * 1M

g_x: i32

Green x * 1M

g_y: i32

Green y * 1M

b_x: i32

Blue x * 1M

b_y: i32

Blue y * 1M

w_x: i32

White x * 1M

w_y: i32

White y * 1M



PrimariesNamed

named primaries

Delivers the primary color volume primaries and white point using an explicitly enumerated named set.

Fields

primaries: WEnum<Primaries>

named primaries



TfPower

transfer characteristic as a power curve

The color component transfer characteristic of this image description is a pure power curve. This event provides the exponent of the power function. This curve represents the conversion from electrical to optical pixel or color values.

The curve exponent has been multiplied by 10000 to get the argument eexp value to carry the precision of 4 decimals.

Fields

eexp: u32

the exponent * 10000



TfNamed

named transfer characteristic

Delivers the transfer characteristic using an explicitly enumerated named function.

Fields

tf: WEnum<TransferFunction>

named transfer function



Luminances

primary color volume luminance range and reference white

Delivers the primary color volume luminance range and the reference white luminance level. These values include the minimum display emission and ambient flare luminances, assumed to be optically additive and have the chromaticity of the primary color volume white point.

The minimum luminance is multiplied by 10000 to get the argument ‘min_lum’ value and carries precision of 4 decimals. The maximum luminance and reference white luminance values are unscaled.

Fields

min_lum: u32

minimum luminance (cd/m²) * 10000

max_lum: u32

maximum luminance (cd/m²)

reference_lum: u32

reference white luminance (cd/m²)



TargetPrimaries

target primaries as chromaticity coordinates

Provides the color primaries and white point of the target color volume using CIE 1931 xy chromaticity coordinates. This is compatible with the SMPTE ST 2086 definition of HDR static metadata for mastering displays.

While primary color volume is about how color is encoded, the target color volume is the actually displayable color volume. If target color volume is equal to the primary color volume, then this event is not sent.

Each coordinate value is multiplied by 1 million to get the argument value to carry precision of 6 decimals.

Fields

r_x: i32

Red x * 1M

r_y: i32

Red y * 1M

g_x: i32

Green x * 1M

g_y: i32

Green y * 1M

b_x: i32

Blue x * 1M

b_y: i32

Blue y * 1M

w_x: i32

White x * 1M

w_y: i32

White y * 1M



TargetLuminance

target luminance range

Provides the luminance range that the image description is targeting as the minimum and maximum absolute luminance L. These values include the minimum display emission and ambient flare luminances, assumed to be optically additive and have the chromaticity of the primary color volume white point. This should be compatible with the SMPTE ST 2086 definition of HDR static metadata.

This luminance range is only theoretical and may not correspond to the luminance of light emitted on an actual display.

Min L value is multiplied by 10000 to get the argument min_lum value and carry precision of 4 decimals. Max L value is unscaled for max_lum.

Fields

min_lum: u32

min L (cd/m²) * 10000

max_lum: u32

max L (cd/m²)



TargetMaxCll

target maximum content light level

Provides the targeted max_cll of the image description. max_cll is defined by CTA-861-H.

This luminance is only theoretical and may not correspond to the luminance of light emitted on an actual display.

Fields

max_cll: u32

Maximum content light-level (cd/m²)



TargetMaxFall

target maximum frame-average light level

Provides the targeted max_fall of the image description. max_fall is defined by CTA-861-H.

This luminance is only theoretical and may not correspond to the luminance of light emitted on an actual display.

Fields

max_fall: u32

Maximum frame-average light level (cd/m²)

Implementations



impl Event

pub fn opcode(&self) -> u16

Get the opcode number of this message